@@ -12,7 +12,7 @@
 /*--------------------------------------------------------------------------*/
 #include "NoMoreScilabMemoryException.hxx"
 /*--------------------------------------------------------------------------*/
-namespace ScilabObjects {
+namespace org_scilab_forge_jims {
 
     NoMoreScilabMemoryException::NoMoreScilabMemoryException(void) throw() : exception() { }
 
