@@ -11,6 +11,9 @@
  */
 /* ------------------------------------------------------------------------- */
 #include <string.h>
+#ifdef _MSC_VER
+#include "strdup_windows.h"
+#endif
 #include "OptionsHelper.h"
 #include "ScilabObjects.hxx"
 #include "ScilabClassLoader.hxx"
@@ -24,11 +27,8 @@
 #include "wrapwithcast.hpp"
 #include "unwrap.hpp"
 #include "WrapAsDirectBufferTemplate.hpp"
-#ifdef _MSC_VER
-#include "strdup_windows.h"
-#endif
 /* ------------------------------------------------------------------------- */
-using namespace ScilabObjects;
+using namespace org_scilab_forge_jims;
 /* ------------------------------------------------------------------------- */
 /*
  * Syntax: wrapForType(type, Type)
@@ -95,7 +95,7 @@ void unwrapstring(int id, int pos, char **errmsg)
         {
             *errmsg = strdup(e.getJavaDescription().c_str());
         }
-        catch (ScilabObjects::NoMoreScilabMemoryException e)
+        catch (org_scilab_forge_jims::NoMoreScilabMemoryException e)
         {
             *errmsg = strdup(e.what());
         }
@@ -115,7 +115,7 @@ void unwraprowstring(int id, int pos, char **errmsg)
         {
             *errmsg = strdup(e.getJavaDescription().c_str());
         }
-        catch (ScilabObjects::NoMoreScilabMemoryException e)
+        catch (org_scilab_forge_jims::NoMoreScilabMemoryException e)
         {
             *errmsg = strdup(e.what());
         }
@@ -135,7 +135,7 @@ void unwrapmatstring(int id, int pos, char **errmsg)
         {
             *errmsg = strdup(e.getJavaDescription().c_str());
         }
-        catch (ScilabObjects::NoMoreScilabMemoryException e)
+        catch (org_scilab_forge_jims::NoMoreScilabMemoryException e)
         {
             *errmsg = strdup(e.what());
         }
@@ -155,7 +155,7 @@ void initscilabjavaobject(char **errmsg)
         {
             *errmsg = strdup(e.getJavaDescription().c_str());
         }
-        catch (ScilabObjects::NoMoreScilabMemoryException e)
+        catch (org_scilab_forge_jims::NoMoreScilabMemoryException e)
         {
             *errmsg = strdup(e.what());
         }
@@ -443,7 +443,7 @@ void getaccessiblemethods(int id, int pos, char **errmsg)
         {
             *errmsg = strdup(e.getJavaDescription().c_str());
         }
-        catch (ScilabObjects::NoMoreScilabMemoryException e)
+        catch (org_scilab_forge_jims::NoMoreScilabMemoryException e)
         {
             *errmsg = strdup(e.what());
         }
@@ -463,7 +463,7 @@ void getaccessiblefields(int id, int pos, char **errmsg)
         {
             *errmsg = strdup(e.getJavaDescription().c_str());
         }
-        catch (ScilabObjects::NoMoreScilabMemoryException e)
+        catch (org_scilab_forge_jims::NoMoreScilabMemoryException e)
         {
             *errmsg = strdup(e.what());
         }
@@ -483,7 +483,7 @@ char* getclassname(int id, char **errmsg)
         {
             *errmsg = strdup(e.getJavaDescription().c_str());
         }
-        catch (ScilabObjects::NoMoreScilabMemoryException e)
+        catch (org_scilab_forge_jims::NoMoreScilabMemoryException e)
         {
             *errmsg = strdup(e.what());
         }
