@@ -10,6 +10,10 @@
  *
  */
 /*--------------------------------------------------------------------------*/
+#include <string.h>
+#ifdef _MSC_VER
+#include <Windows.h>
+#endif
 #include <jni.h>
 #include "ScilabJavaObject.hxx"
 #include "ScilabJavaObjectBis.hxx"
@@ -26,8 +30,8 @@ void ScilabJavaObjectBis::releaseDirectBuffer(JavaVM * jvm_, void** ref, int* ja
     for (;i < len; i++)
     {
         curEnv->DeleteGlobalRef((jobject)(ref[i]));
-        ScilabObjects::ScilabJavaObject::limitDirectBuffer(jvm_, javaID[i]);
-        ScilabObjects::ScilabJavaObject::removeScilabJavaObject(jvm_, javaID[i]);
+        org_scilab_forge_jims::ScilabJavaObject::limitDirectBuffer(jvm_, javaID[i]);
+        org_scilab_forge_jims::ScilabJavaObject::removeScilabJavaObject(jvm_, javaID[i]);
     }
 }
 /*--------------------------------------------------------------------------*/
